import type { IConstruct } from "constructs";
import type { CommonActionProps } from "../action";
import { Action } from "../action";
/**
 * Output structure for the Configure AWS Credentials action.
 *
 * Provides outputs such as AWS account ID, access keys, and session tokens, enabling
 * subsequent steps in the workflow to use AWS credentials securely.
 */
export interface ConfigureAwsCredentialsV4Outputs {
    /**
     * The AWS account ID associated with the configured credentials.
     * This is typically the 12-digit account number linked to the credentials used.
     */
    readonly awsAccountId: string;
    /**
     * The AWS Access Key ID that allows programmatic access to AWS services.
     * This key should be handled securely and kept confidential.
     */
    readonly awsAccessKeyId: string;
    /**
     * The AWS Secret Access Key paired with the AWS Access Key ID.
     * This secret is used to authenticate and authorize requests to AWS.
     * It must be protected to prevent unauthorized access to AWS resources.
     */
    readonly awsSecretAccessKey: string;
    /**
     * A temporary session token associated with the AWS credentials, provided when using
     * temporary security credentials, such as those obtained through role assumption.
     * This token must accompany requests along with the Access Key ID and Secret Access Key.
     */
    readonly awsSessionToken: string;
}
/**
 * Properties for configuring the AWS credentials setup within a GitHub Actions workflow.
 *
 * Extends CommonActionProps to allow AWS-specific options, including access key IDs,
 * session tokens, and optional role assumption parameters.
 */
export interface ConfigureAwsCredentialsV4Props extends CommonActionProps {
    /**
     * AWS region to use for the action. Must be a valid AWS region.
     */
    readonly awsRegion: string;
    /**
     * Optional role ARN to assume for the AWS session.
     */
    readonly roleToAssume?: string;
    /**
     * AWS access key ID to use for credentials.
     */
    readonly awsAccessKeyId?: string;
    /**
     * AWS secret access key associated with the access key ID.
     */
    readonly awsSecretAccessKey?: string;
    /**
     * Session token for temporary AWS credentials.
     */
    readonly awsSessionToken?: string;
    /**
     * Path to a file containing a web identity token, used for assuming a role.
     */
    readonly webIdentityTokenFile?: string;
    /**
     * Duration, in seconds, for the assumed role session.
     */
    readonly roleDurationSeconds?: string;
    readonly roleExternalId?: string;
    /**
     * Name for the assumed role session.
     */
    readonly roleSessionName?: string;
    /**
     * If true, outputs the credentials for use in later steps.
     */
    readonly outputCredentials?: boolean;
    /**
     * Specifies the version of the action to use.
     */
    readonly version?: string;
}
/**
 * Configure AWS Credentials action for GitHub Actions.
 *
 * Enables AWS credentials setup via access keys, session tokens, and role assumption, allowing
 * workflow steps to interact with AWS services.
 */
export declare class ConfigureAwsCredentialsV4 extends Action {
    readonly awsRegion: string;
    readonly roleToAssume?: string;
    readonly awsAccessKeyId?: string;
    readonly awsSecretAccessKey?: string;
    readonly awsSessionToken?: string;
    readonly webIdentityTokenFile?: string;
    readonly roleDurationSeconds?: string;
    readonly roleSessionName?: string;
    readonly outputCredentials?: boolean;
    /**
     * Initializes a new instance of the Configure AWS Credentials action.
     *
     * @param scope - Construct scope in which this action is defined.
     * @param id - Unique identifier for the action within a workflow.
     * @param props - Configuration properties for AWS credentials setup.
     */
    constructor(scope: IConstruct, id: string, props: ConfigureAwsCredentialsV4Props);
    /**
     * Retrieves the outputs of the Configure AWS Credentials action, accessible for use in subsequent workflow steps.
     *
     * @returns AWS credentials outputs including account ID, access key, secret key, and session token.
     */
    get outputs(): ConfigureAwsCredentialsV4Outputs;
}
