import { RootConstruct } from "constructs";
import { Manifest } from "./manifest";
import { type ISynthesisSession } from "./synthesizer";
import { Workflow, type WorkflowProps } from "./workflow";
/**
 * Configuration properties for setting up a `Project` instance.
 */
export interface ProjectProps {
    readonly outdir?: string;
    readonly skipValidation?: boolean;
    readonly additionalChecks?: boolean;
    readonly continueOnErrorAnnotations?: boolean;
}
/**
 * Represents a GitHub Actions project, managing workflows and their output.
 */
export declare class Project extends RootConstruct {
    readonly outdir: string;
    readonly skipValidation?: boolean;
    readonly additionalChecks?: boolean;
    readonly continueOnErrorAnnotations?: boolean;
    readonly manifest: Manifest;
    constructor(props?: ProjectProps);
    addWorkflow(id: string, props: WorkflowProps): Workflow;
    /**
     * Main synthesis process that orchestrates the synthesis steps.
     */
    synth(): void;
    /**
     * Ensures the output directory exists before synthesis.
     */
    protected prepareOutputDir(): void;
    /**
     * Creates a synthesis session object.
     */
    protected createSynthesisSession(): ISynthesisSession;
    /**
     * Synthesizes each workflow and applies additional checks if configured.
     *
     * @param workflows - Array of workflows to synthesize.
     * @param session - Synthesis session information.
     */
    protected synthesizeWorkflows(workflows: Workflow[], session: ISynthesisSession): void;
    /**
     * Handles any errors encountered during synthesis.
     */
    protected handleSynthesisError(error: unknown): void;
    /**
     * Finalizes the synthesis process, printing annotations and handling error annotations.
     */
    protected finalizeSynthesis(): void;
    /**
     * Prints annotations from a workflow manifest to the console.
     *
     * @param manifest - The `IManifest` object containing workflows and their annotations.
     */
    private printManifestAnnotations;
    /**
     * Formats annotation level with icons and descriptions.
     *
     * @param level - The annotation level (INFO, WARN, ERROR).
     * @returns A string with formatted label and icon for the annotation level.
     */
    private formatAnnotationLevel;
}
