import type { IValidation } from "constructs";
import type { Job } from "./job";
import type { RegularStep, RunStep, StepBase } from "./step";
import type { Workflow } from "./workflow";
/**
 * Abstract base class for all validators.
 *
 * @remarks
 * The `Validator` class provides core error management and validation
 * methods, ensuring common validation operations across different
 * workflow constructs. Subclasses implement specific validations based
 * on construct types.
 */
export declare abstract class Validator implements IValidation {
    /**
     * Executes the validation logic for the instance.
     *
     * @returns An array of error messages if validation fails, or an empty array if successful.
     */
    abstract validate(): string[];
    /**
     * Verifies that a required property is set.
     *
     * @param property - The property to check for presence.
     * @param name - The name of the property to include in error messages.
     * @returns An array containing an error message if the property is missing, or an empty array if it exists.
     */
    protected checkRequired(property: unknown, name: string): string[];
}
/**
 * Validator for `Workflow` instances.
 *
 * @remarks
 * Validates properties and configurations specific to workflows, such as
 * cron schedules, environment variables, and shell defaults.
 */
export declare class WorkflowValidator extends Validator {
    private readonly workflow;
    constructor(workflow: Workflow);
    /**
     * Validates various aspects of a workflow's configuration.
     *
     * @returns An array of error messages if validation fails.
     */
    validate(): string[];
}
/**
 * Validator for `Job` instances.
 *
 * @remarks
 * Validates properties of a job within a workflow, including its ID, environment variables, shell type,
 * and the presence of at least one step.
 */
export declare class JobValidator extends Validator {
    private readonly job;
    constructor(job: Job);
    /**
     * Validates the job's configuration, including ID, environment variables, shell type,
     * and the presence of steps.
     *
     * @returns An array of error messages if validation fails.
     */
    validate(): string[];
}
/**
 * Validator for `StepBase` instances.
 *
 * @remarks
 * Validates properties common to all step types within a job, such as ID and environment variables.
 */
export declare class StepBaseValidator extends Validator {
    private readonly step;
    constructor(step: StepBase);
    /**
     * Validates common step properties, including ID format and environment variables.
     *
     * @returns An array of error messages if validation fails.
     */
    validate(): string[];
}
/**
 * Validator for `RunStep` instances.
 *
 * @remarks
 * Validates properties specific to a run step, such as shell type, ensuring
 * compatibility with supported shells.
 */
export declare class RunStepValidator extends Validator {
    private readonly step;
    constructor(step: RunStep);
    /**
     * Validates properties specific to a run step, such as shell type.
     *
     * @returns An array of error messages if validation fails.
     */
    validate(): string[];
}
/**
 * Validator for `RegularStep` instances.
 *
 * @remarks
 * Validates properties specific to a regular step, such as the "uses" format, ensuring it follows
 * the required format for GitHub Actions reusable workflows.
 */
export declare class RegularStepValidator extends Validator {
    private readonly step;
    constructor(step: RegularStep);
    /**
     * Validates properties specific to a regular step, such as the format of the `uses` property.
     *
     * @returns An array of error messages if validation fails.
     */
    validate(): string[];
}
